package com.flyfish.framework.annotations.relation;

import org.springframework.data.annotation.Reference;
import org.springframework.data.annotation.Transient;

import java.lang.annotation.*;

/**
 * 数据库关联信息
 *
 * @author wangyu
 */
@Target({ElementType.FIELD})
@Retention(RetentionPolicy.RUNTIME)
@Documented
@Transient
@Reference
public @interface Association {

    /**
     * @return 关联在本对象上的字段名称
     * 如当前表的detail_id字段对应detail表的id字段，则该值为 detail_id
     */
    String field() default "";

    /**
     * @return 关联在外部对象上的字段名称，注意，禁止循环依赖
     * 如当前表不存在目标表detail的关联id，目标表关联本实体的id为main_id，则该值为main_id。
     * 与field互斥，同时指定永远都以field为主
     */
    String foreignField() default "";
}
